Get historical exchange rates for a specific date for a single or multiple currencies.
get_historical_exchange_rates(date, base_currency = NULL, currencies = NULL)Returns exchange rates for a given time range. Generally, we provide data going back to 1999.
(required) Date to retrieve historical rates from (format: 2021-12-31)
The base currency for the conversion (e.g., "USD")
A list of comma seperated currency codes which you want to get (EUR,USD,CAD) By default all available currencies will be shown